==> api-0.16.0-sources.jar: io/strimzi/api/kafka/model/EntityOperatorSpecFluent.java <==
package io.strimzi.api.kafka.model;

import io.strimzi.api.kafka.model.template.EntityOperatorTemplateBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import io.strimzi.api.kafka.model.template.EntityOperatorTemplateFluent;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.strimzi.api.kafka.model.template.EntityOperatorTemplate;
import io.fabric8.kubernetes.api.model.Toleration;
import java.lang.Long;
import io.fabric8.kubernetes.api.model.Affinity;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

public interface EntityOperatorSpecFluent<A extends EntityOperatorSpecFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildTopicOperator instead.
 * @return The buildable object.
 */
@Deprecated public EntityTopicOperatorSpec getTopicOperator();
    public EntityTopicOperatorSpec buildTopicOperator();
    public A withTopicOperator(EntityTopicOperatorSpec topicOperator);
    public Boolean hasTopicOperator();
    public EntityOperatorSpecFluent.TopicOperatorNested<A> withNewTopicOperator();
    public EntityOperatorSpecFluent.TopicOperatorNested<A> withNewTopicOperatorLike(EntityTopicOperatorSpec item);
    public EntityOperatorSpecFluent.TopicOperatorNested<A> editTopicOperator();
    public EntityOperatorSpecFluent.TopicOperatorNested<A> editOrNewTopicOperator();
    public EntityOperatorSpecFluent.TopicOperatorNested<A> editOrNewTopicOperatorLike(EntityTopicOperatorSpec item);
    
/**
 * This method has been deprecated, please use method buildUserOperator instead.
 * @return The buildable object.
 */
@Deprecated public EntityUserOperatorSpec getUserOperator();
    public EntityUserOperatorSpec buildUserOperator();
    public A withUserOperator(EntityUserOperatorSpec userOperator);
    public Boolean hasUserOperator();
    public EntityOperatorSpecFluent.UserOperatorNested<A> withNewUserOperator();
    public EntityOperatorSpecFluent.UserOperatorNested<A> withNewUserOperatorLike(EntityUserOperatorSpec item);
    public EntityOperatorSpecFluent.UserOperatorNested<A> editUserOperator();
    public EntityOperatorSpecFluent.UserOperatorNested<A> editOrNewUserOperator();
    public EntityOperatorSpecFluent.UserOperatorNested<A> editOrNewUserOperatorLike(EntityUserOperatorSpec item);
    public Affinity getAffinity();
    public A withAffinity(Affinity affinity);
    public Boolean hasAffinity();
    public A addToTolerations(int index,Toleration item);
    public A setToTolerations(int index,Toleration item);
    public A addToTolerations(Toleration... items);
    public A addAllToTolerations(Collection<Toleration> items);
    public A removeFromTolerations(Toleration... items);
    public A removeAllFromTolerations(Collection<Toleration> items);
    public List<Toleration> getTolerations();
    public Toleration getToleration(int index);
    public Toleration getFirstToleration();
    public Toleration getLastToleration();
    public Toleration getMatchingToleration(io.fabric8.kubernetes.api.builder.Predicate<Toleration> predicate);
    public Boolean hasMatchingToleration(io.fabric8.kubernetes.api.builder.Predicate<Toleration> predicate);
    public A withTolerations(List<Toleration> tolerations);
    public A withTolerations(Toleration... tolerations);
    public Boolean hasTolerations();
    public A addNewToleration(String effect,String key,String operator,Long tolerationSeconds,String value);
    
/**
 * This method has been deprecated, please use method buildTlsSidecar instead.
 * @return The buildable object.
 */
@Deprecated public TlsSidecar getTlsSidecar();
    public TlsSidecar buildTlsSidecar();
    public A withTlsSidecar(TlsSidecar tlsSidecar);
    public Boolean hasTlsSidecar();
    public EntityOperatorSpecFluent.TlsSidecarNested<A> withNewTlsSidecar();
    public EntityOperatorSpecFluent.TlsSidecarNested<A> withNewTlsSidecarLike(TlsSidecar item);
    public EntityOperatorSpecFluent.TlsSidecarNested<A> editTlsSidecar();
    public EntityOperatorSpecFluent.TlsSidecarNested<A> editOrNewTlsSidecar();
    public EntityOperatorSpecFluent.TlsSidecarNested<A> editOrNewTlsSidecarLike(TlsSidecar item);
    
/**
 * This method has been deprecated, please use method buildTemplate instead.
 * @return The buildable object.
 */
@Deprecated public EntityOperatorTemplate getTemplate();
    public EntityOperatorTemplate buildTemplate();
    public A withTemplate(EntityOperatorTemplate template);
    public Boolean hasTemplate();
    public EntityOperatorSpecFluent.TemplateNested<A> withNewTemplate();
    public EntityOperatorSpecFluent.TemplateNested<A> withNewTemplateLike(EntityOperatorTemplate item);
    public EntityOperatorSpecFluent.TemplateNested<A> editTemplate();
    public EntityOperatorSpecFluent.TemplateNested<A> editOrNewTemplate();
    public EntityOperatorSpecFluent.TemplateNested<A> editOrNewTemplateLike(EntityOperatorTemplate item);

    public interface TopicOperatorNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,EntityTopicOperatorSpecFluent<EntityOperatorSpecFluent.TopicOperatorNested<N>>{

        
    public N and();    public N endTopicOperator();
}
    public interface UserOperatorNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,EntityUserOperatorSpecFluent<EntityOperatorSpecFluent.UserOperatorNested<N>>{

        
    public N and();    public N endUserOperator();
}
    public interface TlsSidecarNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,TlsSidecarFluent<EntityOperatorSpecFluent.TlsSidecarNested<N>>{

        
    public N and();    public N endTlsSidecar();
}
    public interface TemplateNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,EntityOperatorTemplateFluent<EntityOperatorSpecFluent.TemplateNested<N>>{

        
    public N and();    public N endTemplate();
}


}

==> api-0.21.0-sources.jar: io/strimzi/api/kafka/model/EntityOperatorSpecFluent.java <==
package io.strimzi.api.kafka.model;

import io.strimzi.api.kafka.model.template.EntityOperatorTemplateBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import io.strimzi.api.kafka.model.template.EntityOperatorTemplateFluent;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.strimzi.api.kafka.model.template.EntityOperatorTemplate;
import io.fabric8.kubernetes.api.model.Toleration;
import java.lang.Long;
import io.fabric8.kubernetes.api.model.Affinity;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

public interface EntityOperatorSpecFluent<A extends EntityOperatorSpecFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildTopicOperator instead.
 * @return The buildable object.
 */
@Deprecated public EntityTopicOperatorSpec getTopicOperator();
    public EntityTopicOperatorSpec buildTopicOperator();
    public A withTopicOperator(EntityTopicOperatorSpec topicOperator);
    public Boolean hasTopicOperator();
    public EntityOperatorSpecFluent.TopicOperatorNested<A> withNewTopicOperator();
    public EntityOperatorSpecFluent.TopicOperatorNested<A> withNewTopicOperatorLike(EntityTopicOperatorSpec item);
    public EntityOperatorSpecFluent.TopicOperatorNested<A> editTopicOperator();
    public EntityOperatorSpecFluent.TopicOperatorNested<A> editOrNewTopicOperator();
    public EntityOperatorSpecFluent.TopicOperatorNested<A> editOrNewTopicOperatorLike(EntityTopicOperatorSpec item);
    
/**
 * This method has been deprecated, please use method buildUserOperator instead.
 * @return The buildable object.
 */
@Deprecated public EntityUserOperatorSpec getUserOperator();
    public EntityUserOperatorSpec buildUserOperator();
    public A withUserOperator(EntityUserOperatorSpec userOperator);
    public Boolean hasUserOperator();
    public EntityOperatorSpecFluent.UserOperatorNested<A> withNewUserOperator();
    public EntityOperatorSpecFluent.UserOperatorNested<A> withNewUserOperatorLike(EntityUserOperatorSpec item);
    public EntityOperatorSpecFluent.UserOperatorNested<A> editUserOperator();
    public EntityOperatorSpecFluent.UserOperatorNested<A> editOrNewUserOperator();
    public EntityOperatorSpecFluent.UserOperatorNested<A> editOrNewUserOperatorLike(EntityUserOperatorSpec item);
    public Affinity getAffinity();
    public A withAffinity(Affinity affinity);
    public Boolean hasAffinity();
    public A addToTolerations(int index,Toleration item);
    public A setToTolerations(int index,Toleration item);
    public A addToTolerations(Toleration... items);
    public A addAllToTolerations(Collection<Toleration> items);
    public A removeFromTolerations(Toleration... items);
    public A removeAllFromTolerations(Collection<Toleration> items);
    public java.util.List<Toleration> getTolerations();
    public Toleration getToleration(int index);
    public Toleration getFirstToleration();
    public Toleration getLastToleration();
    public Toleration getMatchingToleration(io.fabric8.kubernetes.api.builder.Predicate<Toleration> predicate);
    public Boolean hasMatchingToleration(io.fabric8.kubernetes.api.builder.Predicate<Toleration> predicate);
    public A withTolerations(java.util.List<Toleration> tolerations);
    public A withTolerations(Toleration... tolerations);
    public Boolean hasTolerations();
    public A addNewToleration(String effect,String key,String operator,Long tolerationSeconds,String value);
    
/**
 * This method has been deprecated, please use method buildTlsSidecar instead.
 * @return The buildable object.
 */
@Deprecated public TlsSidecar getTlsSidecar();
    public TlsSidecar buildTlsSidecar();
    public A withTlsSidecar(TlsSidecar tlsSidecar);
    public Boolean hasTlsSidecar();
    public EntityOperatorSpecFluent.TlsSidecarNested<A> withNewTlsSidecar();
    public EntityOperatorSpecFluent.TlsSidecarNested<A> withNewTlsSidecarLike(TlsSidecar item);
    public EntityOperatorSpecFluent.TlsSidecarNested<A> editTlsSidecar();
    public EntityOperatorSpecFluent.TlsSidecarNested<A> editOrNewTlsSidecar();
    public EntityOperatorSpecFluent.TlsSidecarNested<A> editOrNewTlsSidecarLike(TlsSidecar item);
    
/**
 * This method has been deprecated, please use method buildTemplate instead.
 * @return The buildable object.
 */
@Deprecated public EntityOperatorTemplate getTemplate();
    public EntityOperatorTemplate buildTemplate();
    public A withTemplate(EntityOperatorTemplate template);
    public Boolean hasTemplate();
    public EntityOperatorSpecFluent.TemplateNested<A> withNewTemplate();
    public EntityOperatorSpecFluent.TemplateNested<A> withNewTemplateLike(EntityOperatorTemplate item);
    public EntityOperatorSpecFluent.TemplateNested<A> editTemplate();
    public EntityOperatorSpecFluent.TemplateNested<A> editOrNewTemplate();
    public EntityOperatorSpecFluent.TemplateNested<A> editOrNewTemplateLike(EntityOperatorTemplate item);

    public interface TopicOperatorNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,EntityTopicOperatorSpecFluent<EntityOperatorSpecFluent.TopicOperatorNested<N>>{

        
    public N and();    public N endTopicOperator();
}
    public interface UserOperatorNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,EntityUserOperatorSpecFluent<EntityOperatorSpecFluent.UserOperatorNested<N>>{

        
    public N and();    public N endUserOperator();
}
    public interface TlsSidecarNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,TlsSidecarFluent<EntityOperatorSpecFluent.TlsSidecarNested<N>>{

        
    public N and();    public N endTlsSidecar();
}
    public interface TemplateNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,EntityOperatorTemplateFluent<EntityOperatorSpecFluent.TemplateNested<N>>{

        
    public N and();    public N endTemplate();
}


}
